@@ -24,6 +24,6 @@ typedef Eo Efl_Ui_Grid_Default_Item;
  */
 #define EFL_UI_GRID_DEFAULT_ITEM_CLASS efl_ui_grid_default_item_class_get()
 
-EWAPI const Efl_Class *efl_ui_grid_default_item_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_grid_default_item_class_get(void) EINA_CONST;
 
 #endif
